/*******************************************************************************
* File Name: main.c
*
* Version: 1.00
*
* Description:
*  This is the source code for the example project of the RTC_P4 component.
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation. All rights reserved.
* This software is owned by Cypress Semiconductor Corporation and is protected
* by and subject to worldwide patent and copyright laws and treaties.
* Therefore, you may use this software only as provided in the license agreement
* accompanying the software package from which you obtained this software.
* CYPRESS AND ITS SUPPLIERS MAKE NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
* WITH REGARD TO THIS SOFTWARE, INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT,
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
*******************************************************************************/

#include <project.h>
#include <stdio.h>

#define LFCLK_CYCLES_PER_SECOND     (32768u)
#define WCO_STARTUP_DELAY_CYCLES    (LFCLK_CYCLES_PER_SECOND)

#define TICK_EACH_1_HZ      (1u)

/* Alarm flag initialization */
uint32 alarmFlag = 0;

/* Interrupt prototypes */
CY_ISR_PROTO(EnableRtcOperation);
CY_ISR_PROTO(UpdateTimeIsrHandler);
CY_ISR_PROTO(UpdateTimeIsrHandler1);
CY_ISR_PROTO(AlarmIsrHandler);


/*******************************************************************************
* Function Name: main
********************************************************************************
*
* Summary:
*  The main() function.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
int main()
{
    char timeBuffer[16u];
    char dateBuffer[16u];


    uint32 time;
    uint32 date;

    /* Enable WCO */
    CySysClkWcoStart();
    
    /* Enable global interrupts */
    CyGlobalIntEnable;

    /* Prepare COUNTER0 to use it by CySysTimerDelay function in
     * "INTERRUPT" mode: disable "clear on match" functionality, configure
     * COUNTER0 to generate interrupts on match.
     */
    CySysWdtSetClearOnMatch(CY_SYS_WDT_COUNTER0, 0u);
    CySysWdtSetMode(CY_SYS_WDT_COUNTER0, CY_SYS_WDT_MODE_INT);
    CySysWdtSetClearOnMatch(CY_SYS_WDT_COUNTER1, 0u);
    CySysWdtSetMode(CY_SYS_WDT_COUNTER1, CY_SYS_WDT_MODE_INT);
    
    /* Enable WDT COUNTER0 */
    CySysWdtEnable(CY_SYS_WDT_COUNTER0_MASK);
    CySysWdtEnable(CY_SYS_WDT_COUNTER1_MASK);
    
    /* Disable servicing interrupts from WDT_COUNTER0 to prevent
       trigger callback before the CySysTimerDelay() function. */
    CySysWdtDisableCounterIsr(CY_SYS_WDT_COUNTER0);
    CySysWdtDisableCounterIsr(CY_SYS_WDT_COUNTER1);
    /* Register EnableRtcOperation() by the COUNTER0. */
    CySysWdtSetInterruptCallback(CY_SYS_WDT_COUNTER0, EnableRtcOperation);
    CySysWdtSetInterruptCallback(CY_SYS_WDT_COUNTER1, EnableRtcOperation);
    /* Initiate run the EnableRtcOperation() callback in WCO_STARTUP_DELAY_CYCLES interval. */
    CySysTimerDelay(CY_SYS_WDT_COUNTER0, CY_SYS_TIMER_INTERRUPT, WCO_STARTUP_DELAY_CYCLES);
    CySysTimerDelay(CY_SYS_WDT_COUNTER1, CY_SYS_TIMER_INTERRUPT, WCO_STARTUP_DELAY_CYCLES);
    /* Start RTC component */
    RTC_Start();
    
    /* Set RTC time update period */
    RTC_SetPeriod(1u, TICK_EACH_1_HZ);

    while(1)
    {

        /* Get Date and Time from RTC */
        time = RTC_GetTime();
        date = RTC_GetDate();

        /* Print Date and Time to UART */
        sprintf(timeBuffer, "%02lu:%02lu:%02lu", RTC_GetHours(time), RTC_GetMinutes(time), RTC_GetSecond(time));
        sprintf(dateBuffer, "%02lu/%02lu/%02lu", RTC_GetMonth(date), RTC_GetDay(date), RTC_GetYear(date));

        UART_PutString(timeBuffer);
        UART_PutString(" | ");
        UART_PutString(dateBuffer);
        UART_PutString(" | ");

        if (alarmFlag == 1u)
        {
            UART_PutString("  LED off ");
            alarmFlag  = 0u;
        }
        else
        {
            UART_PutString("Two LED working");
        }

        UART_PutString("\r");

        /* Switch to Sleep Mode */
        CySysPmDeepSleep();
    }
}


/*******************************************************************************
* Function Name: UpdateTimeIsrHandler
********************************************************************************
* Summary: 
*  This interrupt handler is intended to switch LFCLK source from ILO to WCO and
*  enable RTC operation. 
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void EnableRtcOperation(void)
{
    /* Switch LFCLK source from ILO to WCO. */
    CySysClkSetLfclkSource(CY_SYS_CLK_LFCLK_SRC_WCO);
    
    /* Configure COUNTER0 to generate interrupt every second. */
    CySysWdtDisable(CY_SYS_WDT_COUNTER0_MASK);
    CySysWdtSetClearOnMatch(CY_SYS_WDT_COUNTER0, 1u);
    CySysWdtSetMatch(CY_SYS_WDT_COUNTER0, LFCLK_CYCLES_PER_SECOND);
    CySysWdtEnable(CY_SYS_WDT_COUNTER0_MASK);
    
     CySysWdtDisable(CY_SYS_WDT_COUNTER1_MASK);
    CySysWdtSetClearOnMatch(CY_SYS_WDT_COUNTER1, 1u);
    CySysWdtSetMatch(CY_SYS_WDT_COUNTER1, LFCLK_CYCLES_PER_SECOND);
    CySysWdtEnable(CY_SYS_WDT_COUNTER1_MASK);
    /* Register UpdateTimeIsrHandler() by the COUNTER0. */
    CySysWdtSetInterruptCallback(CY_SYS_WDT_COUNTER0, UpdateTimeIsrHandler);
       
    CySysWdtSetInterruptCallback(CY_SYS_WDT_COUNTER1, UpdateTimeIsrHandler1);
    /* Enable the COUNTER0 ISR handler. */
    CySysWdtEnableCounterIsr(CY_SYS_WDT_COUNTER0);
    CySysWdtEnableCounterIsr(CY_SYS_WDT_COUNTER1);
    
    /* Configure the LFCLK_Out pin to drive it by LFCLK. */
    LFCLK_Out_SetDriveMode(LFCLK_Out_DM_STRONG);
}


/*******************************************************************************
* Function Name: UpdateTimeIsrHandler
********************************************************************************
* Summary: 
*  The interrupt handler for WDT counter 0 interrupts. Toggles the LED_WdtIsr 
*  pin.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void UpdateTimeIsrHandler(void)
{
    uint8 i;
    uint ondelay,offdelay;
    char NoOfCycles[16u],Ondly[16u],Offdly[16u];
    
    ondelay=1000;
    offdelay=2000;
     UART_PutString("\nRED LED\nOndelay:");
    sprintf(Ondly, "%d", ondelay);
    UART_PutString(Ondly);
     UART_PutString("\nOffdelay:");
    sprintf(Offdly, "%d", offdelay);
    UART_PutString(Offdly);
    UART_PutString("\n NoOfCycles of RED LED\n");
    /* Toggle pin state */
   for(i=1;i<=4;i++)
{
    
    LED_WdtIsr_Write(0);
    CyDelay(ondelay);
    LED_WdtIsr_Write(1);
    CyDelay(offdelay);
    sprintf(NoOfCycles, "%d", i);
    UART_PutString(NoOfCycles);
    UART_PutString("\n ");
}
     
    RTC_Update();
    CySysWdtSetInterruptCallback(CY_SYS_WDT_COUNTER0, AlarmIsrHandler);
  
}


/*******************************************************************************
* Function Name: AlarmIsrHandler
********************************************************************************
* Summary:
*  The interrupt handler for Alarm interrupts. Toggles the LED_WdtInt pin.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void AlarmIsrHandler(void)
{
    alarmFlag = 1u;

     LED_Alarm_Write(1);
 LED_WdtIsr_Write(1);
    
}
void UpdateTimeIsrHandler1(void)
{
    uint8 i;
    uint ondelay,offdelay;
    char NoOfCycles[16u],Ondly[16u],Offdly[16u];
    
    ondelay=3000;
    offdelay=1000;
    UART_PutString("\nBLUE LED\nOndelay:");
    sprintf(Ondly, "%d", ondelay);
    UART_PutString(Ondly);
    
     UART_PutString("\nOffdelay:");
    sprintf(Offdly, "%d", offdelay);
    UART_PutString(Offdly);
    UART_PutString("\n NoOfCycles of BLUE LED\n");
    /* Toggle pin state */
   for(i=1;i<=4;i++)
{
     LED_Alarm_Write(0);
    CyDelay(ondelay);
    LED_Alarm_Write(1);
    CyDelay(offdelay);
    
    sprintf(NoOfCycles, "%d", i);
    UART_PutString(NoOfCycles);
    UART_PutString("\n ");
}
     
    RTC_Update();
    CySysWdtSetInterruptCallback(CY_SYS_WDT_COUNTER1, AlarmIsrHandler);
  
}

/* [] END OF FILE */
